@@ -12,7 +12,8 @@ from nereid.globals import session, request
 from nereid.signals import login, failed_login
 from flask_oauth import OAuth
 from trytond.model import fields
-from trytond.pool import PoolMeta
+from trytond.pool import PoolMeta, Pool
+from trytond.transaction import Transaction
 
 from .i18n import _
 
@@ -86,6 +87,8 @@ class NereidUser:
         """Authorized handler to which linkedin will redirect the user to
         after the login attempt is made.
         """
+        Party = Pool().get('party.party')
+
         linkedin = request.nereid_website.get_linkedin_oauth_client()
         if linkedin is None:
             return redirect(
@@ -132,27 +135,24 @@ class NereidUser:
         session.pop('linkedin_oauth_token')
 
         # Find the user
-        users = cls.search([
-            ('email', '=', email.data),
-            ('company', '=', request.nereid_website.company.id),
-        ])
+        with Transaction().set_context(active_test=False):
+            users = cls.search([
+                ('email', '=', email.data),
+                ('company', '=', request.nereid_website.company.id),
+            ])
         if not users:
             current_app.logger.debug(
                 "No LinkedIn user with email %s" % email.data
             )
-            current_app.logger.debug(
-                "Registering new user %s %s" % (
-                    me.data['firstName'], me.data['lastName']
-                )
-            )
             name = u'%s %s' % (me.data['firstName'], me.data['lastName'])
-            user = cls.create({
-                'name': name,
+            current_app.logger.debug("Registering new user %s" % name)
+            user, = cls.create([{
+                'party': Party.create([{'name': name}])[0].id,
                 'display_name': name,
                 'email': email.data,
                 'linkedin_auth': True,
-                'addresses': False,
-            })
+                'active': True,
+            }])
             flash(
                 _('Thanks for registering with us using linkedin')
             )
@@ -164,7 +164,7 @@ class NereidUser:
         if not user.linkedin_auth:
             cls.write([user], {'linkedin_auth': True})
         flash(_(
-            "You are now logged in. Welcome %(name)s", name=user.name
+            "You are now logged in. Welcome %(name)s", name=user.rec_name
         ))
         login.send()
         if request.is_xhr:
